import { getContactAllService, searchContactsByIdChatbotActiveService } from "@/feature/messenger/services/chat/OptionsMessageService"
import useConfigChatStore from "@/feature/messenger/store/chat_store/useConfigChatStore";
import useConversationsStore from "@/feature/messenger/store/chat_store/useConversationsStore";
import useMessagesStore from "@/feature/messenger/store/chat_store/useMessagesStore";
import { debounce } from 'lodash';

import { create } from 'zustand'

type TypeContacts = {
    listContact: [],
    defaultListContact: [],
    timeConsult: Date
    contactSelected: any,
    openModalContact: boolean
    handlerOpenModalContact: () => void
    hadlerSelectContactOption: () => void
    selectedContact: (e:any,value: any) => void,
    searchContacts: (search: string) => void

}
const getIdChatbot = () => {
    const id_chatbot =  useConfigChatStore.getState().idChatbot;
    return id_chatbot
}

const handleResetSelectedConversation = () => {
    const resetSelectedConversation = useConversationsStore.getState().actions.resetSelectedConversation;
    resetSelectedConversation();
    const clearListMessages = useMessagesStore.getState().actions.clearListMessages;
    clearListMessages();
}
const useListContactStore = create<TypeContacts>((set, get) => ({
    listContact: [],
    defaultListContact:[],
    timeConsult: new Date(),
    contactSelected: {},
    openModalContact: false,
    handlerOpenModalContact: () => set((state) => ({ ...state, openModalContact: !state.openModalContact })),
    hadlerSelectContactOption: () => {
        // Obtener la fecha actual
        let date = new Date();
        // Restar 5 minutos a la fecha actual
        date.setMinutes(date.getMinutes() - 2);
        if (get().timeConsult <= date || get().listContact.length == 0) {
            const id_chatbot = getIdChatbot();
            getContactAllService(id_chatbot)
            .then((res) => {
                if (res?.success == true) {
                    set({ listContact: res.data })
                    set({ defaultListContact: res.data })
                    set({ timeConsult: new Date() })
                } else {
                    set({ listContact: [] })
                    set({ defaultListContact: [] })
                }
            })
            
        }
        handleResetSelectedConversation();
        set({ contactSelected: {} })
        document.querySelectorAll(".contact-log-main li").forEach((item) => {
            item.classList.remove("active");
        });
        const chatContentElement = document.querySelector(".chat-content");
        if (chatContentElement) {
            chatContentElement.classList.remove("active");
        }
    },
    selectedContact: (e: any,value: any) => {
        set({ contactSelected: value })
        get().handlerOpenModalContact();
    },
    searchContacts: debounce((search: string) => {
        const id_chatbot = getIdChatbot();
        if (search.length > 2) {
            searchContactsByIdChatbotActiveService(id_chatbot, search)
            .then((res) => {
                if (res?.success == true) {
                    set({ listContact: res.data })
                }
            })
        } else {
            set({ listContact: get().defaultListContact })
        }
    }, 500),
}));

export default useListContactStore